@@ -1,4 +1,4 @@
-## $Id: AllClasses.R 414 2011-02-22 17:11:25Z sgibb $
+## $Id: AllClasses.R 446 2011-03-10 16:44:59Z sgibb $
 ##
 ## Copyright 2011 Sebastian Gibb
 ## <mail@sebastiangibb.de>
@@ -30,3 +30,7 @@ setClass("AbstractSpectrumData",
 setClass("SingleSpectrum",
     contains="AbstractSpectrumData");
 
+## represent a peak list from a single spectrum
+setClass("SinglePeakList",
+    contains="AbstractSpectrumData");
+
